@@ -4,4 +4,4 @@ from __future__ import absolute_import
 from .gutenberg_cleaner import strip_headers  # noqa
 
 
-__all__ = ['gutenberg_cleaner']
+__all__ = ['gutenberg_cleaner', 'io']
